@@ -44,7 +44,13 @@ class Vue:
 
 
     def is_road(self, position):
-        r, g, b = self.map_img_rgb.getpixel(tuple(position))
+        try :
+            r, g, b = self.map_img_rgb.getpixel(tuple(position))
+        except IndexError :
+            r, g, b = 250, 250, 250
+        except:
+            raise
+            
         r_road , g_road, b_road = self.metadata['road_rgb']
         if (r-r_road)+(g-g_road)+(b-b_road) < 50 :
             return True
